# aspire: Accelerated Sequential Posterior Inference via REuse

aspire is a framework for reusing existing posterior samples to obtain new results at a reduced cost.

## Installation

aspire can be installed from PyPI using `pip`

```
pip install aspire-inference
```

**Important:** the name of `aspire` on PyPI is `aspire-inference` but once installed
the package can be imported and used as `aspire`.

## Documentation

See the [documentation on ReadTheDocs][docs].

## Citation

If you use `aspire` in your work please cite the [DOI][DOI] and [paper][paper].


[docs]: https://aspire.readthedocs.io/
[DOI]: https://doi.org/10.5281/zenodo.15658747
[paper]: https://arxiv.org/abs/2511.04218
